==> rice-kim-impl-2.1.13-sources.jar: org/kuali/rice/kim/impl/common/delegate/DelegateMemberBo.java <==
package org.kuali.rice.kim.impl.common.delegate;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@javax.persistence.Entity() @javax.persistence.Table(name="KRIM_DLGN_MBR_T") public class DelegateMemberBo
  extends org.kuali.rice.kim.impl.membership.AbstractMemberBo  implements
    org.kuali.rice.kim.api.common.delegate.DelegateMemberContract,    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.String getDelegationMemberId() { return (java.lang.String)null;}
public  void setDelegationMemberId(java.lang.String value) { }
public  java.lang.String getDelegationId() { return (java.lang.String)null;}
public  void setDelegationId(java.lang.String value) { }
public  java.lang.String getRoleMemberId() { return (java.lang.String)null;}
public  void setRoleMemberId(java.lang.String value) { }
public  void setAttributes(java.util.Map<java.lang.String, java.lang.String> value) { }
public  java.util.Map<java.lang.String, java.lang.String> getQualifier() { return (java.util.Map<java.lang.String, java.lang.String>)null;}
public  java.util.List<org.kuali.rice.kim.impl.common.delegate.DelegateMemberAttributeDataBo> getAttributeDetails() { return (java.util.List<org.kuali.rice.kim.impl.common.delegate.DelegateMemberAttributeDataBo>)null;}
public  void setAttributeDetails(java.util.List<org.kuali.rice.kim.impl.common.delegate.DelegateMemberAttributeDataBo> attributeDetails) { }
public  java.util.Map<java.lang.String, java.lang.String> getAttributes() { return (java.util.Map<java.lang.String, java.lang.String>)null;}
public static  org.kuali.rice.kim.api.common.delegate.DelegateMember to(org.kuali.rice.kim.impl.common.delegate.DelegateMemberBo bo) { return (org.kuali.rice.kim.api.common.delegate.DelegateMember)null;}
public static  org.kuali.rice.kim.impl.common.delegate.DelegateMemberBo from(org.kuali.rice.kim.api.common.delegate.DelegateMember immutable) { return (org.kuali.rice.kim.impl.common.delegate.DelegateMemberBo)null;}
@java.lang.Override() public  java.util.List buildListOfDeletionAwareLists() { return (java.util.List)null;}
}

==> rice-kim-impl-2.3.14-sources.jar: org/kuali/rice/kim/impl/common/delegate/DelegateMemberBo.java <==
package org.kuali.rice.kim.impl.common.delegate;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

@javax.persistence.Entity() @javax.persistence.Table(name="KRIM_DLGN_MBR_T") public class DelegateMemberBo
  extends org.kuali.rice.kim.impl.membership.AbstractMemberBo  implements
    org.kuali.rice.kim.api.common.delegate.DelegateMemberContract {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.String getDelegationMemberId() { return (java.lang.String)null;}
public  void setDelegationMemberId(java.lang.String value) { }
public  java.lang.String getDelegationId() { return (java.lang.String)null;}
public  void setDelegationId(java.lang.String value) { }
public  java.lang.String getRoleMemberId() { return (java.lang.String)null;}
public  void setRoleMemberId(java.lang.String value) { }
public  void setAttributes(java.util.Map<java.lang.String, java.lang.String> value) { }
public  java.util.Map<java.lang.String, java.lang.String> getQualifier() { return (java.util.Map<java.lang.String, java.lang.String>)null;}
public  java.util.List<org.kuali.rice.kim.impl.common.delegate.DelegateMemberAttributeDataBo> getAttributeDetails() { return (java.util.List<org.kuali.rice.kim.impl.common.delegate.DelegateMemberAttributeDataBo>)null;}
public  void setAttributeDetails(java.util.List<org.kuali.rice.kim.impl.common.delegate.DelegateMemberAttributeDataBo> attributeDetails) { }
public  java.util.Map<java.lang.String, java.lang.String> getAttributes() { return (java.util.Map<java.lang.String, java.lang.String>)null;}
public static  org.kuali.rice.kim.api.common.delegate.DelegateMember to(org.kuali.rice.kim.impl.common.delegate.DelegateMemberBo bo) { return (org.kuali.rice.kim.api.common.delegate.DelegateMember)null;}
public static  org.kuali.rice.kim.impl.common.delegate.DelegateMemberBo from(org.kuali.rice.kim.api.common.delegate.DelegateMember immutable) { return (org.kuali.rice.kim.impl.common.delegate.DelegateMemberBo)null;}
@java.lang.Override() public  java.util.List buildListOfDeletionAwareLists() { return (java.util.List)null;}
}
